@@ -1,4 +1,4 @@
-from __future__ import absolute_import
+from contextlib import suppress
 
 from .file import File
 from .dict import Dict
@@ -7,12 +7,11 @@ from .encode import Encode
 from .pickle import Pickle
 from .python import Python
 from .compressed import *
-from .utils import ignoring
-with ignoring(ImportError):
+with suppress(ImportError):
     from .numpy import Numpy
-with ignoring(ImportError):
+with suppress(ImportError):
     from .pandas import PandasColumns, PandasBlocks
-with ignoring(ImportError):
+with suppress(ImportError):
     from .zmq import Client, Server
 
 from ._version import get_versions
